==> 0.0.1%2B1.tar.gz: lib/models/IR5ArtGroup.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

// --------------------------------------------------------------------------------
part 'IR5ArtGroup.g.dart';

/** Articles Groupes */
@JsonSerializable(explicitToJson: true)
class IR5ArtGroup {
  IR5ArtGroup({
    required this.Num,
    required this.Nom,
    required this.Description,
    required this.NomFr,
    required this.NomNl,
    required this.NomUk,
    required this.ExtRef,
    required this.Tags,
    required this.WebOrder,
    required this.Account,
    required this.BtnProp,
    required this.Flags,
  });

  factory IR5ArtGroup.fromJson(Map<String, dynamic>? json) => _$IR5ArtGroupFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ArtGroupToJson(this);

  /** Just a #Num used as primary key unique id */
  @JsonKey(defaultValue: 0)
  final int Num;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomFr;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomNl;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomUk;

  /** External Ref (used as primary key) */
  @JsonKey(defaultValue: '')
  final String ExtRef;

  /** Free Tags or Labels semicolumn separated */
  @JsonKey(defaultValue: '')
  final String Tags;

  /** Export to WebOrder Platforms (semicolumn separated list of Platforms)
   * Export ModePay if ModePay.WebOrder
   * Export Article if Article.WebOrder or Article.Categ.WebOrder or Article.Group.WebOrder
   */
  @JsonKey(defaultValue: '')
  final String WebOrder;
  @JsonKey(defaultValue: '')
  final String Account;

  final IR5BtnProperties? BtnProp;

  /** Art.Groupe Flags
   *   Bit 30 : StayInGroupe
   *   Bit 31 : GotoSearchList
   */
  @JsonKey(defaultValue: 0)
  final num Flags;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5ArtGroup.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;

// --------------------------------------------------------------------------------
part 'IR5ArtGroup.g.dart';

/** Articles Groupes */
@JsonSerializable(explicitToJson: true)
class IR5ArtGroup {
  IR5ArtGroup({
    required this.Num,
    required this.Nom,
    required this.Description,
    required this.NomFr,
    required this.NomNl,
    required this.NomUk,
    required this.ExtRef,
    required this.Tags,
    required this.WebOrder,
    required this.Account,
    required this.BtnProp,
    required this.Flags,
  });

  factory IR5ArtGroup.fromJson(Map<String, dynamic>? json) =>
      _$IR5ArtGroupFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5ArtGroupToJson(this);

  /** Just a #Num used as primary key unique id */
  @JsonKey(defaultValue: 0)
  final int Num;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String Nom;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomFr;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomNl;

  /** Just a Name */
  @JsonKey(defaultValue: '')
  final String NomUk;

  /** External Ref (used as primary key) */
  @JsonKey(defaultValue: '')
  final String ExtRef;

  /** Free Tags or Labels semicolumn separated */
  @JsonKey(defaultValue: '')
  final String Tags;

  /** Export to WebOrder Platforms (semicolumn separated list of Platforms)
   * Export ModePay if ModePay.WebOrder
   * Export Article if Article.WebOrder or Article.Categ.WebOrder or Article.Group.WebOrder
   */
  @JsonKey(defaultValue: '')
  final String WebOrder;
  @JsonKey(defaultValue: '')
  final String Account;

  final IR5BtnProperties? BtnProp;

  /** Art.Groupe Flags
   *   Bit 30 : StayInGroupe
   *   Bit 31 : GotoSearchList
   */
  @JsonKey(defaultValue: 0)
  final num Flags;
}
